﻿# Remove the specified file if it exists.
function RemoveFile([string]$path)
{
	If (Test-Path $path)
	{
		Remove-Item $path
	}
}

# Wait for a keypress.
function Pause
{
    Write-Host "Press any key to continue ..."
    $x = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
}

# Upload all files in the specified folder (including subdirectories) to
# the specified FTP folder.
# Adapted from https://gist.github.com/chardcastle/1003539
function FTPUpload($sourceFolder, $targetFolder)
{
	# Get the FTP server settings.
	$settings = Get-Content DontDeploy\ftp.txt
	$ftp = $settings[0]
	$user = $settings[1]
	$pass = $settings[2]

	# Create a WebClient object.
	$webclient = New-Object System.Net.WebClient 
	$webclient.Credentials = New-Object System.Net.NetworkCredential($user, $pass)  

	# Upload all files in all subdirectories of the folder.
	foreach($item in (Get-ChildItem -Path $sourceFolder -Recurse -File))
	{
		try
		{
			# Get the source file.
			$source = $item.DirectoryName + "\" + $item;
			
			# Get the directory on the FTP site.
			$directory = "";
			if ($item.DirectoryName.Length -gt 0)
			{
				$directory = $item.DirectoryName.Replace($sourceFolder, "")
				$directory = $directory.Replace("\", "/")
			}
			$directory += "/"
			
			# Create the complete target path and upload it.
			$target = $ftp + $targetFolder + $directory + $item

			Write-Host Uploading $item.FullName to $target
			
			$uri = New-Object System.Uri($target)
			$webclient.UploadFile($uri, $item.FullName)
		}
		catch [Exception]
		{
			# Log if something failed.
			Write-Host $_.Exception.Message;
			$content = "`r`nFile " + $item.FullName + "`r`n" + 
				$_.Exception.Message + "`r`n"
			Add-Content BuildLog.txt $content
		}
	}
}

# Erase the log file.
RemoveFile BuildLog.txt

# Get the current folder.
$currFolder = Get-Location

# Find the location of VFP.
$regEntry = Get-ItemProperty -Path Registry::HKEY_CLASSES_ROOT\Visual.FoxPro.Application.9\shell\open\command
$value = $regEntry.'(default)'
$file = $value.Substring(1, $value.IndexOf('"', 2) - 1)
$VFPexe = Get-ChildItem $file

# Build the project. Note that we pipe the output to Out-Null, which forces PowerShell
# to wait until it's done executing.
Write-Host "Building executable"
$buildConfig = "-c$currFolder\Build.fpw"
& $VFPexe -t $buildConfig | Out-Null

# Find the location of Signtool.
$regEntry = Get-ItemProperty -Path "Registry::HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Microsoft SDKs\Windows\v7.1A"
$value = $regEntry.'InstallationFolder'
$file = $value + "Bin\signtool.exe"
$signTool = Get-ChildItem $file

# Get the password for the certificate.
$password = Get-Content DontDeploy\certpw.txt
$parms = 'sign', '/f', "$currFolder\DontDeploy\mycert.pfx", '/p', $password

# Sign the exe.
Write-Host "Signing executable"
$signParms = $parms + '/d', 'My Application', 'MyApp\myapp.exe'
& $signTool $signParms

# Find the location of the Inno Setup compiler.
$regEntry = Get-ItemProperty -Path Registry::HKEY_CLASSES_ROOT\InnoSetupScriptFile\Shell\Compile\Command
$value = $regEntry.'(default)'
$file = $value.Substring(1, $value.IndexOf('"', 2) - 1)
$exe = Get-ChildItem $file
$innoCompiler = $exe.DirectoryName + "\iscc"

# Build Setup.exe.
$signParms = "/sStandard=$signTool $parms $" + "p"
& $innoCompiler $signParms myapp.iss

# Upload Setup.exe.
Write-host "============ Uploading Setup.exe"
$sourcePath = Join-Path $currFolder "Output"
FTPUpload $sourcePath "httpdocs/Downloads/Sample"

# If anything went wrong , display a message.
If (Test-Path BuildLog.txt)
{
    Write-Host "See BuildLog.txt for a list of errors in the process."
    Pause
}

